# NewEntryTemplate.pl
# New Entry Template v1.4 plugin for Movable Type
# http://www.chipple.net/mt/newentrytemplate/
# by Patrick Benny http://www.chipple.net/
# This code cannot be redistributed without permission from the author. 
#
# Version history
#   1.4 - 2008/5/28 - Fixed to not overwrite fields already containing data
#                     (conflicted with Copy! plugin)
#   1.3 - 2007/8/7  - Now supports Movable Type 4.0
#   1.2 - 2006/7/10 - Added "Tags" field for Movable Type 3.3 users
#   1.1 - 2006/7/6  - Added support for Movable Type 3.3
#   1.0 - 2006/7/3  - First public release


use strict;
package MT::Plugin::NewEntryTemplate;

use vars qw( $VERSION );
$VERSION = '1.4';

use MT;
use MT::Plugin;


# Create plugin
my $plugin = MT::Plugin->new({
    name => "New Entry Template",
    description => 'Allows setting global or per-blog default content for entry text fields.',
    doc_link => 'http://www.chipple.net/mt/newentrytemplate/',
    author_name => 'Patrick Benny',
    author_link => 'http://www.chipple.net/',
    config_template => MT->version_id ge '4' ? 'config.tmpl' : 'config.mt3.tmpl',
    settings => new MT::PluginSettings([
        ['title',     { Default => '' }],
        ['text',      { Default => '' }],
        ['text_more', { Default => '' }],
        ['excerpt',   { Default => '' }],
        ['keywords',  { Default => '' }],
        ['tags',      { Default => '' }],
        # To show "Tags" field for MT3.3+
        ['_mt33',     { Default => MT->version_id ge '3.3' ? '1' : '' }],
    ]),
    version => $VERSION,
});
MT->add_plugin($plugin);

## For Movable Type 4.0
# Use template_param to set default values on edit_entry page (only on new entry)
MT->add_callback('MT::App::CMS::template_param.edit_entry', 9, $plugin, \&_param);

## For Movable Type 3.3+
# Use AppTemplateParam to set default values on edit_entry page (only on new entry)
MT->add_callback('MT::App::CMS::AppTemplateParam.edit_entry', 9, $plugin, \&_param);

## For Movable Type 3.2
# Use BigPAPI to set default values on edit_entry page (only on new entry)
MT->add_callback('bigpapi::param::edit_entry', 9, $plugin, \&_param);


#################
### UTILITIES ###
#################

sub apply_default_settings {
    my $plugin = shift;
    my ($data, $scope) = @_;
    if ($scope ne 'system') {
        my $sys = $plugin->get_config_obj('system');
        my $sysdata = $sys->data();
        if ($plugin->{settings} && $sysdata) {
            foreach (keys %$sysdata) {
                $data->{$_} = $sysdata->{$_}
                    if (!exists $data->{$_}) || (!defined $data->{$_});
            }
        }
    } else {
        $plugin->SUPER::apply_default_settings(@_);
    }
}


################
### TEMPLATE ###
################

# Set default values on edit_entry page (only on new entry)
sub _param {

    my ($cb, $app, $param) = @_;
    return unless $param->{'id'} eq '';

    my $cfg_obj = $plugin->get_config_obj('blog:' . $param->{'blog_id'});
    $cfg_obj = $plugin->get_config_obj('system') if $cfg_obj->id eq '';
    if ($cfg_obj->id ne '') {
        my $cfg_data = $cfg_obj->data();
        $param->{'title'}     = $cfg_data->{'title'}     if $param->{'title'} eq '';
        $param->{'text'}      = $cfg_data->{'text'}      if $param->{'text'} eq '';
        $param->{'text_more'} = $cfg_data->{'text_more'} if $param->{'text_more'} eq '';
        $param->{'excerpt'}   = $cfg_data->{'excerpt'}   if $param->{'excerpt'} eq '';
        $param->{'keywords'}  = $cfg_data->{'keywords'}  if $param->{'keywords'} eq '';
        $param->{'tags'}      = $cfg_data->{'tags'}      if $param->{'tags'} eq '';
    }

}

1;